# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DashboardArgs', 'Dashboard']

@pulumi.input_type
class DashboardArgs:
    def __init__(__self__, *,
                 display_name: pulumi.Input[_builtins.str],
                 parent_path: pulumi.Input[_builtins.str],
                 warehouse_id: pulumi.Input[_builtins.str],
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 dashboard_change_detected: Optional[pulumi.Input[_builtins.bool]] = None,
                 dashboard_id: Optional[pulumi.Input[_builtins.str]] = None,
                 dataset_catalog: Optional[pulumi.Input[_builtins.str]] = None,
                 dataset_schema: Optional[pulumi.Input[_builtins.str]] = None,
                 embed_credentials: Optional[pulumi.Input[_builtins.bool]] = None,
                 etag: Optional[pulumi.Input[_builtins.str]] = None,
                 file_path: Optional[pulumi.Input[_builtins.str]] = None,
                 lifecycle_state: Optional[pulumi.Input[_builtins.str]] = None,
                 md5: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['DashboardProviderConfigArgs']] = None,
                 serialized_dashboard: Optional[pulumi.Input[_builtins.str]] = None,
                 update_time: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Dashboard resource.
        :param pulumi.Input[_builtins.str] display_name: The display name of the dashboard.
        :param pulumi.Input[_builtins.str] parent_path: The workspace path of the folder containing the dashboard. Includes leading slash and no trailing slash.  If folder doesn't exist, it will be created.
        :param pulumi.Input[_builtins.str] warehouse_id: The warehouse ID used to run the dashboard.
        :param pulumi.Input[_builtins.str] dataset_catalog: Sets the default catalog for all datasets in this dashboard. Does not impact table references that use fully qualified catalog names (ex: samples.nyctaxi.trips).
        :param pulumi.Input[_builtins.str] dataset_schema: Sets the default schema for all datasets in this dashboard. Does not impact table references that use fully qualified catalog names (ex: samples.nyctaxi.trips).
        :param pulumi.Input[_builtins.bool] embed_credentials: Whether to embed credentials in the dashboard. Default is `true`.
        :param pulumi.Input[_builtins.str] file_path: The path to the dashboard JSON file. Conflicts with `serialized_dashboard`.
        :param pulumi.Input['DashboardProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] serialized_dashboard: The contents of the dashboard in serialized string form. Conflicts with `file_path`.
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "parent_path", parent_path)
        pulumi.set(__self__, "warehouse_id", warehouse_id)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if dashboard_change_detected is not None:
            pulumi.set(__self__, "dashboard_change_detected", dashboard_change_detected)
        if dashboard_id is not None:
            pulumi.set(__self__, "dashboard_id", dashboard_id)
        if dataset_catalog is not None:
            pulumi.set(__self__, "dataset_catalog", dataset_catalog)
        if dataset_schema is not None:
            pulumi.set(__self__, "dataset_schema", dataset_schema)
        if embed_credentials is not None:
            pulumi.set(__self__, "embed_credentials", embed_credentials)
        if etag is not None:
            pulumi.set(__self__, "etag", etag)
        if file_path is not None:
            pulumi.set(__self__, "file_path", file_path)
        if lifecycle_state is not None:
            pulumi.set(__self__, "lifecycle_state", lifecycle_state)
        if md5 is not None:
            pulumi.set(__self__, "md5", md5)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if serialized_dashboard is not None:
            pulumi.set(__self__, "serialized_dashboard", serialized_dashboard)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[_builtins.str]:
        """
        The display name of the dashboard.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter(name="parentPath")
    def parent_path(self) -> pulumi.Input[_builtins.str]:
        """
        The workspace path of the folder containing the dashboard. Includes leading slash and no trailing slash.  If folder doesn't exist, it will be created.
        """
        return pulumi.get(self, "parent_path")

    @parent_path.setter
    def parent_path(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "parent_path", value)

    @_builtins.property
    @pulumi.getter(name="warehouseId")
    def warehouse_id(self) -> pulumi.Input[_builtins.str]:
        """
        The warehouse ID used to run the dashboard.
        """
        return pulumi.get(self, "warehouse_id")

    @warehouse_id.setter
    def warehouse_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "warehouse_id", value)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "create_time", value)

    @_builtins.property
    @pulumi.getter(name="dashboardChangeDetected")
    def dashboard_change_detected(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "dashboard_change_detected")

    @dashboard_change_detected.setter
    def dashboard_change_detected(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "dashboard_change_detected", value)

    @_builtins.property
    @pulumi.getter(name="dashboardId")
    def dashboard_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "dashboard_id")

    @dashboard_id.setter
    def dashboard_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dashboard_id", value)

    @_builtins.property
    @pulumi.getter(name="datasetCatalog")
    def dataset_catalog(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Sets the default catalog for all datasets in this dashboard. Does not impact table references that use fully qualified catalog names (ex: samples.nyctaxi.trips).
        """
        return pulumi.get(self, "dataset_catalog")

    @dataset_catalog.setter
    def dataset_catalog(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dataset_catalog", value)

    @_builtins.property
    @pulumi.getter(name="datasetSchema")
    def dataset_schema(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Sets the default schema for all datasets in this dashboard. Does not impact table references that use fully qualified catalog names (ex: samples.nyctaxi.trips).
        """
        return pulumi.get(self, "dataset_schema")

    @dataset_schema.setter
    def dataset_schema(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dataset_schema", value)

    @_builtins.property
    @pulumi.getter(name="embedCredentials")
    def embed_credentials(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to embed credentials in the dashboard. Default is `true`.
        """
        return pulumi.get(self, "embed_credentials")

    @embed_credentials.setter
    def embed_credentials(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "embed_credentials", value)

    @_builtins.property
    @pulumi.getter
    def etag(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "etag")

    @etag.setter
    def etag(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "etag", value)

    @_builtins.property
    @pulumi.getter(name="filePath")
    def file_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The path to the dashboard JSON file. Conflicts with `serialized_dashboard`.
        """
        return pulumi.get(self, "file_path")

    @file_path.setter
    def file_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "file_path", value)

    @_builtins.property
    @pulumi.getter(name="lifecycleState")
    def lifecycle_state(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "lifecycle_state")

    @lifecycle_state.setter
    def lifecycle_state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "lifecycle_state", value)

    @_builtins.property
    @pulumi.getter
    def md5(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "md5")

    @md5.setter
    def md5(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "md5", value)

    @_builtins.property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "path", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['DashboardProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['DashboardProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="serializedDashboard")
    def serialized_dashboard(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The contents of the dashboard in serialized string form. Conflicts with `file_path`.
        """
        return pulumi.get(self, "serialized_dashboard")

    @serialized_dashboard.setter
    def serialized_dashboard(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "serialized_dashboard", value)

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "update_time", value)


@pulumi.input_type
class _DashboardState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 dashboard_change_detected: Optional[pulumi.Input[_builtins.bool]] = None,
                 dashboard_id: Optional[pulumi.Input[_builtins.str]] = None,
                 dataset_catalog: Optional[pulumi.Input[_builtins.str]] = None,
                 dataset_schema: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 embed_credentials: Optional[pulumi.Input[_builtins.bool]] = None,
                 etag: Optional[pulumi.Input[_builtins.str]] = None,
                 file_path: Optional[pulumi.Input[_builtins.str]] = None,
                 lifecycle_state: Optional[pulumi.Input[_builtins.str]] = None,
                 md5: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_path: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['DashboardProviderConfigArgs']] = None,
                 serialized_dashboard: Optional[pulumi.Input[_builtins.str]] = None,
                 update_time: Optional[pulumi.Input[_builtins.str]] = None,
                 warehouse_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Dashboard resources.
        :param pulumi.Input[_builtins.str] dataset_catalog: Sets the default catalog for all datasets in this dashboard. Does not impact table references that use fully qualified catalog names (ex: samples.nyctaxi.trips).
        :param pulumi.Input[_builtins.str] dataset_schema: Sets the default schema for all datasets in this dashboard. Does not impact table references that use fully qualified catalog names (ex: samples.nyctaxi.trips).
        :param pulumi.Input[_builtins.str] display_name: The display name of the dashboard.
        :param pulumi.Input[_builtins.bool] embed_credentials: Whether to embed credentials in the dashboard. Default is `true`.
        :param pulumi.Input[_builtins.str] file_path: The path to the dashboard JSON file. Conflicts with `serialized_dashboard`.
        :param pulumi.Input[_builtins.str] parent_path: The workspace path of the folder containing the dashboard. Includes leading slash and no trailing slash.  If folder doesn't exist, it will be created.
        :param pulumi.Input['DashboardProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] serialized_dashboard: The contents of the dashboard in serialized string form. Conflicts with `file_path`.
        :param pulumi.Input[_builtins.str] warehouse_id: The warehouse ID used to run the dashboard.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if dashboard_change_detected is not None:
            pulumi.set(__self__, "dashboard_change_detected", dashboard_change_detected)
        if dashboard_id is not None:
            pulumi.set(__self__, "dashboard_id", dashboard_id)
        if dataset_catalog is not None:
            pulumi.set(__self__, "dataset_catalog", dataset_catalog)
        if dataset_schema is not None:
            pulumi.set(__self__, "dataset_schema", dataset_schema)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if embed_credentials is not None:
            pulumi.set(__self__, "embed_credentials", embed_credentials)
        if etag is not None:
            pulumi.set(__self__, "etag", etag)
        if file_path is not None:
            pulumi.set(__self__, "file_path", file_path)
        if lifecycle_state is not None:
            pulumi.set(__self__, "lifecycle_state", lifecycle_state)
        if md5 is not None:
            pulumi.set(__self__, "md5", md5)
        if parent_path is not None:
            pulumi.set(__self__, "parent_path", parent_path)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if serialized_dashboard is not None:
            pulumi.set(__self__, "serialized_dashboard", serialized_dashboard)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)
        if warehouse_id is not None:
            pulumi.set(__self__, "warehouse_id", warehouse_id)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "create_time", value)

    @_builtins.property
    @pulumi.getter(name="dashboardChangeDetected")
    def dashboard_change_detected(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "dashboard_change_detected")

    @dashboard_change_detected.setter
    def dashboard_change_detected(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "dashboard_change_detected", value)

    @_builtins.property
    @pulumi.getter(name="dashboardId")
    def dashboard_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "dashboard_id")

    @dashboard_id.setter
    def dashboard_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dashboard_id", value)

    @_builtins.property
    @pulumi.getter(name="datasetCatalog")
    def dataset_catalog(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Sets the default catalog for all datasets in this dashboard. Does not impact table references that use fully qualified catalog names (ex: samples.nyctaxi.trips).
        """
        return pulumi.get(self, "dataset_catalog")

    @dataset_catalog.setter
    def dataset_catalog(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dataset_catalog", value)

    @_builtins.property
    @pulumi.getter(name="datasetSchema")
    def dataset_schema(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Sets the default schema for all datasets in this dashboard. Does not impact table references that use fully qualified catalog names (ex: samples.nyctaxi.trips).
        """
        return pulumi.get(self, "dataset_schema")

    @dataset_schema.setter
    def dataset_schema(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dataset_schema", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The display name of the dashboard.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter(name="embedCredentials")
    def embed_credentials(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to embed credentials in the dashboard. Default is `true`.
        """
        return pulumi.get(self, "embed_credentials")

    @embed_credentials.setter
    def embed_credentials(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "embed_credentials", value)

    @_builtins.property
    @pulumi.getter
    def etag(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "etag")

    @etag.setter
    def etag(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "etag", value)

    @_builtins.property
    @pulumi.getter(name="filePath")
    def file_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The path to the dashboard JSON file. Conflicts with `serialized_dashboard`.
        """
        return pulumi.get(self, "file_path")

    @file_path.setter
    def file_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "file_path", value)

    @_builtins.property
    @pulumi.getter(name="lifecycleState")
    def lifecycle_state(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "lifecycle_state")

    @lifecycle_state.setter
    def lifecycle_state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "lifecycle_state", value)

    @_builtins.property
    @pulumi.getter
    def md5(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "md5")

    @md5.setter
    def md5(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "md5", value)

    @_builtins.property
    @pulumi.getter(name="parentPath")
    def parent_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The workspace path of the folder containing the dashboard. Includes leading slash and no trailing slash.  If folder doesn't exist, it will be created.
        """
        return pulumi.get(self, "parent_path")

    @parent_path.setter
    def parent_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent_path", value)

    @_builtins.property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "path", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['DashboardProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['DashboardProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="serializedDashboard")
    def serialized_dashboard(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The contents of the dashboard in serialized string form. Conflicts with `file_path`.
        """
        return pulumi.get(self, "serialized_dashboard")

    @serialized_dashboard.setter
    def serialized_dashboard(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "serialized_dashboard", value)

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "update_time", value)

    @_builtins.property
    @pulumi.getter(name="warehouseId")
    def warehouse_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The warehouse ID used to run the dashboard.
        """
        return pulumi.get(self, "warehouse_id")

    @warehouse_id.setter
    def warehouse_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "warehouse_id", value)


@pulumi.type_token("databricks:index/dashboard:Dashboard")
class Dashboard(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 dashboard_change_detected: Optional[pulumi.Input[_builtins.bool]] = None,
                 dashboard_id: Optional[pulumi.Input[_builtins.str]] = None,
                 dataset_catalog: Optional[pulumi.Input[_builtins.str]] = None,
                 dataset_schema: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 embed_credentials: Optional[pulumi.Input[_builtins.bool]] = None,
                 etag: Optional[pulumi.Input[_builtins.str]] = None,
                 file_path: Optional[pulumi.Input[_builtins.str]] = None,
                 lifecycle_state: Optional[pulumi.Input[_builtins.str]] = None,
                 md5: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_path: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['DashboardProviderConfigArgs', 'DashboardProviderConfigArgsDict']]] = None,
                 serialized_dashboard: Optional[pulumi.Input[_builtins.str]] = None,
                 update_time: Optional[pulumi.Input[_builtins.str]] = None,
                 warehouse_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        This resource allows you to manage Databricks [Dashboards](https://docs.databricks.com/en/dashboards/index.html). To manage [Dashboards](https://docs.databricks.com/en/dashboards/index.html) you must have a warehouse access on your databricks workspace.

        > This resource can only be used with a workspace-level provider!

        ## Example Usage

        Dashboard using `serialized_dashboard` attribute:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        starter = databricks.get_sql_warehouse(name="Starter Warehouse")
        dashboard = databricks.Dashboard("dashboard",
            display_name="New Dashboard",
            warehouse_id=starter.id,
            serialized_dashboard="{\\"pages\\":[{\\"name\\":\\"new_name\\",\\"displayName\\":\\"New Page\\"}]}",
            embed_credentials=False,
            parent_path="/Shared/provider-test")
        ```

        Dashboard using `file_path` attribute:

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] dataset_catalog: Sets the default catalog for all datasets in this dashboard. Does not impact table references that use fully qualified catalog names (ex: samples.nyctaxi.trips).
        :param pulumi.Input[_builtins.str] dataset_schema: Sets the default schema for all datasets in this dashboard. Does not impact table references that use fully qualified catalog names (ex: samples.nyctaxi.trips).
        :param pulumi.Input[_builtins.str] display_name: The display name of the dashboard.
        :param pulumi.Input[_builtins.bool] embed_credentials: Whether to embed credentials in the dashboard. Default is `true`.
        :param pulumi.Input[_builtins.str] file_path: The path to the dashboard JSON file. Conflicts with `serialized_dashboard`.
        :param pulumi.Input[_builtins.str] parent_path: The workspace path of the folder containing the dashboard. Includes leading slash and no trailing slash.  If folder doesn't exist, it will be created.
        :param pulumi.Input[Union['DashboardProviderConfigArgs', 'DashboardProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] serialized_dashboard: The contents of the dashboard in serialized string form. Conflicts with `file_path`.
        :param pulumi.Input[_builtins.str] warehouse_id: The warehouse ID used to run the dashboard.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DashboardArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource allows you to manage Databricks [Dashboards](https://docs.databricks.com/en/dashboards/index.html). To manage [Dashboards](https://docs.databricks.com/en/dashboards/index.html) you must have a warehouse access on your databricks workspace.

        > This resource can only be used with a workspace-level provider!

        ## Example Usage

        Dashboard using `serialized_dashboard` attribute:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        starter = databricks.get_sql_warehouse(name="Starter Warehouse")
        dashboard = databricks.Dashboard("dashboard",
            display_name="New Dashboard",
            warehouse_id=starter.id,
            serialized_dashboard="{\\"pages\\":[{\\"name\\":\\"new_name\\",\\"displayName\\":\\"New Page\\"}]}",
            embed_credentials=False,
            parent_path="/Shared/provider-test")
        ```

        Dashboard using `file_path` attribute:

        :param str resource_name: The name of the resource.
        :param DashboardArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DashboardArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 dashboard_change_detected: Optional[pulumi.Input[_builtins.bool]] = None,
                 dashboard_id: Optional[pulumi.Input[_builtins.str]] = None,
                 dataset_catalog: Optional[pulumi.Input[_builtins.str]] = None,
                 dataset_schema: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 embed_credentials: Optional[pulumi.Input[_builtins.bool]] = None,
                 etag: Optional[pulumi.Input[_builtins.str]] = None,
                 file_path: Optional[pulumi.Input[_builtins.str]] = None,
                 lifecycle_state: Optional[pulumi.Input[_builtins.str]] = None,
                 md5: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_path: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['DashboardProviderConfigArgs', 'DashboardProviderConfigArgsDict']]] = None,
                 serialized_dashboard: Optional[pulumi.Input[_builtins.str]] = None,
                 update_time: Optional[pulumi.Input[_builtins.str]] = None,
                 warehouse_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DashboardArgs.__new__(DashboardArgs)

            __props__.__dict__["create_time"] = create_time
            __props__.__dict__["dashboard_change_detected"] = dashboard_change_detected
            __props__.__dict__["dashboard_id"] = dashboard_id
            __props__.__dict__["dataset_catalog"] = dataset_catalog
            __props__.__dict__["dataset_schema"] = dataset_schema
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["embed_credentials"] = embed_credentials
            __props__.__dict__["etag"] = etag
            __props__.__dict__["file_path"] = file_path
            __props__.__dict__["lifecycle_state"] = lifecycle_state
            __props__.__dict__["md5"] = md5
            if parent_path is None and not opts.urn:
                raise TypeError("Missing required property 'parent_path'")
            __props__.__dict__["parent_path"] = parent_path
            __props__.__dict__["path"] = path
            __props__.__dict__["provider_config"] = provider_config
            __props__.__dict__["serialized_dashboard"] = serialized_dashboard
            __props__.__dict__["update_time"] = update_time
            if warehouse_id is None and not opts.urn:
                raise TypeError("Missing required property 'warehouse_id'")
            __props__.__dict__["warehouse_id"] = warehouse_id
        super(Dashboard, __self__).__init__(
            'databricks:index/dashboard:Dashboard',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[_builtins.str]] = None,
            dashboard_change_detected: Optional[pulumi.Input[_builtins.bool]] = None,
            dashboard_id: Optional[pulumi.Input[_builtins.str]] = None,
            dataset_catalog: Optional[pulumi.Input[_builtins.str]] = None,
            dataset_schema: Optional[pulumi.Input[_builtins.str]] = None,
            display_name: Optional[pulumi.Input[_builtins.str]] = None,
            embed_credentials: Optional[pulumi.Input[_builtins.bool]] = None,
            etag: Optional[pulumi.Input[_builtins.str]] = None,
            file_path: Optional[pulumi.Input[_builtins.str]] = None,
            lifecycle_state: Optional[pulumi.Input[_builtins.str]] = None,
            md5: Optional[pulumi.Input[_builtins.str]] = None,
            parent_path: Optional[pulumi.Input[_builtins.str]] = None,
            path: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['DashboardProviderConfigArgs', 'DashboardProviderConfigArgsDict']]] = None,
            serialized_dashboard: Optional[pulumi.Input[_builtins.str]] = None,
            update_time: Optional[pulumi.Input[_builtins.str]] = None,
            warehouse_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'Dashboard':
        """
        Get an existing Dashboard resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] dataset_catalog: Sets the default catalog for all datasets in this dashboard. Does not impact table references that use fully qualified catalog names (ex: samples.nyctaxi.trips).
        :param pulumi.Input[_builtins.str] dataset_schema: Sets the default schema for all datasets in this dashboard. Does not impact table references that use fully qualified catalog names (ex: samples.nyctaxi.trips).
        :param pulumi.Input[_builtins.str] display_name: The display name of the dashboard.
        :param pulumi.Input[_builtins.bool] embed_credentials: Whether to embed credentials in the dashboard. Default is `true`.
        :param pulumi.Input[_builtins.str] file_path: The path to the dashboard JSON file. Conflicts with `serialized_dashboard`.
        :param pulumi.Input[_builtins.str] parent_path: The workspace path of the folder containing the dashboard. Includes leading slash and no trailing slash.  If folder doesn't exist, it will be created.
        :param pulumi.Input[Union['DashboardProviderConfigArgs', 'DashboardProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] serialized_dashboard: The contents of the dashboard in serialized string form. Conflicts with `file_path`.
        :param pulumi.Input[_builtins.str] warehouse_id: The warehouse ID used to run the dashboard.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DashboardState.__new__(_DashboardState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["dashboard_change_detected"] = dashboard_change_detected
        __props__.__dict__["dashboard_id"] = dashboard_id
        __props__.__dict__["dataset_catalog"] = dataset_catalog
        __props__.__dict__["dataset_schema"] = dataset_schema
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["embed_credentials"] = embed_credentials
        __props__.__dict__["etag"] = etag
        __props__.__dict__["file_path"] = file_path
        __props__.__dict__["lifecycle_state"] = lifecycle_state
        __props__.__dict__["md5"] = md5
        __props__.__dict__["parent_path"] = parent_path
        __props__.__dict__["path"] = path
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["serialized_dashboard"] = serialized_dashboard
        __props__.__dict__["update_time"] = update_time
        __props__.__dict__["warehouse_id"] = warehouse_id
        return Dashboard(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter(name="dashboardChangeDetected")
    def dashboard_change_detected(self) -> pulumi.Output[Optional[_builtins.bool]]:
        return pulumi.get(self, "dashboard_change_detected")

    @_builtins.property
    @pulumi.getter(name="dashboardId")
    def dashboard_id(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "dashboard_id")

    @_builtins.property
    @pulumi.getter(name="datasetCatalog")
    def dataset_catalog(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Sets the default catalog for all datasets in this dashboard. Does not impact table references that use fully qualified catalog names (ex: samples.nyctaxi.trips).
        """
        return pulumi.get(self, "dataset_catalog")

    @_builtins.property
    @pulumi.getter(name="datasetSchema")
    def dataset_schema(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Sets the default schema for all datasets in this dashboard. Does not impact table references that use fully qualified catalog names (ex: samples.nyctaxi.trips).
        """
        return pulumi.get(self, "dataset_schema")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[_builtins.str]:
        """
        The display name of the dashboard.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter(name="embedCredentials")
    def embed_credentials(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether to embed credentials in the dashboard. Default is `true`.
        """
        return pulumi.get(self, "embed_credentials")

    @_builtins.property
    @pulumi.getter
    def etag(self) -> pulumi.Output[Optional[_builtins.str]]:
        return pulumi.get(self, "etag")

    @_builtins.property
    @pulumi.getter(name="filePath")
    def file_path(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The path to the dashboard JSON file. Conflicts with `serialized_dashboard`.
        """
        return pulumi.get(self, "file_path")

    @_builtins.property
    @pulumi.getter(name="lifecycleState")
    def lifecycle_state(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "lifecycle_state")

    @_builtins.property
    @pulumi.getter
    def md5(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "md5")

    @_builtins.property
    @pulumi.getter(name="parentPath")
    def parent_path(self) -> pulumi.Output[_builtins.str]:
        """
        The workspace path of the folder containing the dashboard. Includes leading slash and no trailing slash.  If folder doesn't exist, it will be created.
        """
        return pulumi.get(self, "parent_path")

    @_builtins.property
    @pulumi.getter
    def path(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "path")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.DashboardProviderConfig']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="serializedDashboard")
    def serialized_dashboard(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The contents of the dashboard in serialized string form. Conflicts with `file_path`.
        """
        return pulumi.get(self, "serialized_dashboard")

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "update_time")

    @_builtins.property
    @pulumi.getter(name="warehouseId")
    def warehouse_id(self) -> pulumi.Output[_builtins.str]:
        """
        The warehouse ID used to run the dashboard.
        """
        return pulumi.get(self, "warehouse_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['QualityMonitorV2Args', 'QualityMonitorV2']

@pulumi.input_type
class QualityMonitorV2Args:
    def __init__(__self__, *,
                 object_id: pulumi.Input[_builtins.str],
                 object_type: pulumi.Input[_builtins.str],
                 provider_config: Optional[pulumi.Input['QualityMonitorV2ProviderConfigArgs']] = None,
                 validity_check_configurations: Optional[pulumi.Input[Sequence[pulumi.Input['QualityMonitorV2ValidityCheckConfigurationArgs']]]] = None):
        """
        The set of arguments for constructing a QualityMonitorV2 resource.
        :param pulumi.Input[_builtins.str] object_id: The uuid of the request object. For example, schema id
        :param pulumi.Input[_builtins.str] object_type: The type of the monitored object. Can be one of the following: schema
        :param pulumi.Input['QualityMonitorV2ProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[Sequence[pulumi.Input['QualityMonitorV2ValidityCheckConfigurationArgs']]] validity_check_configurations: Validity check configurations for anomaly detection
        """
        pulumi.set(__self__, "object_id", object_id)
        pulumi.set(__self__, "object_type", object_type)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if validity_check_configurations is not None:
            pulumi.set(__self__, "validity_check_configurations", validity_check_configurations)

    @_builtins.property
    @pulumi.getter(name="objectId")
    def object_id(self) -> pulumi.Input[_builtins.str]:
        """
        The uuid of the request object. For example, schema id
        """
        return pulumi.get(self, "object_id")

    @object_id.setter
    def object_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "object_id", value)

    @_builtins.property
    @pulumi.getter(name="objectType")
    def object_type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of the monitored object. Can be one of the following: schema
        """
        return pulumi.get(self, "object_type")

    @object_type.setter
    def object_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "object_type", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['QualityMonitorV2ProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['QualityMonitorV2ProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="validityCheckConfigurations")
    def validity_check_configurations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['QualityMonitorV2ValidityCheckConfigurationArgs']]]]:
        """
        Validity check configurations for anomaly detection
        """
        return pulumi.get(self, "validity_check_configurations")

    @validity_check_configurations.setter
    def validity_check_configurations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['QualityMonitorV2ValidityCheckConfigurationArgs']]]]):
        pulumi.set(self, "validity_check_configurations", value)


@pulumi.input_type
class _QualityMonitorV2State:
    def __init__(__self__, *,
                 anomaly_detection_config: Optional[pulumi.Input['QualityMonitorV2AnomalyDetectionConfigArgs']] = None,
                 object_id: Optional[pulumi.Input[_builtins.str]] = None,
                 object_type: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['QualityMonitorV2ProviderConfigArgs']] = None,
                 validity_check_configurations: Optional[pulumi.Input[Sequence[pulumi.Input['QualityMonitorV2ValidityCheckConfigurationArgs']]]] = None):
        """
        Input properties used for looking up and filtering QualityMonitorV2 resources.
        :param pulumi.Input['QualityMonitorV2AnomalyDetectionConfigArgs'] anomaly_detection_config: (AnomalyDetectionConfig)
        :param pulumi.Input[_builtins.str] object_id: The uuid of the request object. For example, schema id
        :param pulumi.Input[_builtins.str] object_type: The type of the monitored object. Can be one of the following: schema
        :param pulumi.Input['QualityMonitorV2ProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[Sequence[pulumi.Input['QualityMonitorV2ValidityCheckConfigurationArgs']]] validity_check_configurations: Validity check configurations for anomaly detection
        """
        if anomaly_detection_config is not None:
            pulumi.set(__self__, "anomaly_detection_config", anomaly_detection_config)
        if object_id is not None:
            pulumi.set(__self__, "object_id", object_id)
        if object_type is not None:
            pulumi.set(__self__, "object_type", object_type)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if validity_check_configurations is not None:
            pulumi.set(__self__, "validity_check_configurations", validity_check_configurations)

    @_builtins.property
    @pulumi.getter(name="anomalyDetectionConfig")
    def anomaly_detection_config(self) -> Optional[pulumi.Input['QualityMonitorV2AnomalyDetectionConfigArgs']]:
        """
        (AnomalyDetectionConfig)
        """
        return pulumi.get(self, "anomaly_detection_config")

    @anomaly_detection_config.setter
    def anomaly_detection_config(self, value: Optional[pulumi.Input['QualityMonitorV2AnomalyDetectionConfigArgs']]):
        pulumi.set(self, "anomaly_detection_config", value)

    @_builtins.property
    @pulumi.getter(name="objectId")
    def object_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The uuid of the request object. For example, schema id
        """
        return pulumi.get(self, "object_id")

    @object_id.setter
    def object_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "object_id", value)

    @_builtins.property
    @pulumi.getter(name="objectType")
    def object_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the monitored object. Can be one of the following: schema
        """
        return pulumi.get(self, "object_type")

    @object_type.setter
    def object_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "object_type", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['QualityMonitorV2ProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['QualityMonitorV2ProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="validityCheckConfigurations")
    def validity_check_configurations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['QualityMonitorV2ValidityCheckConfigurationArgs']]]]:
        """
        Validity check configurations for anomaly detection
        """
        return pulumi.get(self, "validity_check_configurations")

    @validity_check_configurations.setter
    def validity_check_configurations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['QualityMonitorV2ValidityCheckConfigurationArgs']]]]):
        pulumi.set(self, "validity_check_configurations", value)


@pulumi.type_token("databricks:index/qualityMonitorV2:QualityMonitorV2")
class QualityMonitorV2(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 object_id: Optional[pulumi.Input[_builtins.str]] = None,
                 object_type: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['QualityMonitorV2ProviderConfigArgs', 'QualityMonitorV2ProviderConfigArgsDict']]] = None,
                 validity_check_configurations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['QualityMonitorV2ValidityCheckConfigurationArgs', 'QualityMonitorV2ValidityCheckConfigurationArgsDict']]]]] = None,
                 __props__=None):
        """
        [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

        > **Deprecated** This resource is deprecated. Please use `DataQualityMonitor` instead.

        Users with MANAGE Schema can use quality monitor v2 to set up data quality monitoring checks for UC objects, currently support schema.

        > **Note** This resource can only be used with an workspace-level provider!

        ## Example Usage

        > **Deprecated** This resource is deprecated. Please use `DataQualityMonitor` instead.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.Schema("this",
            catalog_name="my_catalog",
            name="my_schema")
        this_quality_monitor_v2 = databricks.QualityMonitorV2("this",
            object_type="schema",
            object_id=this.schema_id)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] object_id: The uuid of the request object. For example, schema id
        :param pulumi.Input[_builtins.str] object_type: The type of the monitored object. Can be one of the following: schema
        :param pulumi.Input[Union['QualityMonitorV2ProviderConfigArgs', 'QualityMonitorV2ProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[Sequence[pulumi.Input[Union['QualityMonitorV2ValidityCheckConfigurationArgs', 'QualityMonitorV2ValidityCheckConfigurationArgsDict']]]] validity_check_configurations: Validity check configurations for anomaly detection
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: QualityMonitorV2Args,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

        > **Deprecated** This resource is deprecated. Please use `DataQualityMonitor` instead.

        Users with MANAGE Schema can use quality monitor v2 to set up data quality monitoring checks for UC objects, currently support schema.

        > **Note** This resource can only be used with an workspace-level provider!

        ## Example Usage

        > **Deprecated** This resource is deprecated. Please use `DataQualityMonitor` instead.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.Schema("this",
            catalog_name="my_catalog",
            name="my_schema")
        this_quality_monitor_v2 = databricks.QualityMonitorV2("this",
            object_type="schema",
            object_id=this.schema_id)
        ```

        :param str resource_name: The name of the resource.
        :param QualityMonitorV2Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(QualityMonitorV2Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 object_id: Optional[pulumi.Input[_builtins.str]] = None,
                 object_type: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['QualityMonitorV2ProviderConfigArgs', 'QualityMonitorV2ProviderConfigArgsDict']]] = None,
                 validity_check_configurations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['QualityMonitorV2ValidityCheckConfigurationArgs', 'QualityMonitorV2ValidityCheckConfigurationArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = QualityMonitorV2Args.__new__(QualityMonitorV2Args)

            if object_id is None and not opts.urn:
                raise TypeError("Missing required property 'object_id'")
            __props__.__dict__["object_id"] = object_id
            if object_type is None and not opts.urn:
                raise TypeError("Missing required property 'object_type'")
            __props__.__dict__["object_type"] = object_type
            __props__.__dict__["provider_config"] = provider_config
            __props__.__dict__["validity_check_configurations"] = validity_check_configurations
            __props__.__dict__["anomaly_detection_config"] = None
        super(QualityMonitorV2, __self__).__init__(
            'databricks:index/qualityMonitorV2:QualityMonitorV2',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            anomaly_detection_config: Optional[pulumi.Input[Union['QualityMonitorV2AnomalyDetectionConfigArgs', 'QualityMonitorV2AnomalyDetectionConfigArgsDict']]] = None,
            object_id: Optional[pulumi.Input[_builtins.str]] = None,
            object_type: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['QualityMonitorV2ProviderConfigArgs', 'QualityMonitorV2ProviderConfigArgsDict']]] = None,
            validity_check_configurations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['QualityMonitorV2ValidityCheckConfigurationArgs', 'QualityMonitorV2ValidityCheckConfigurationArgsDict']]]]] = None) -> 'QualityMonitorV2':
        """
        Get an existing QualityMonitorV2 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['QualityMonitorV2AnomalyDetectionConfigArgs', 'QualityMonitorV2AnomalyDetectionConfigArgsDict']] anomaly_detection_config: (AnomalyDetectionConfig)
        :param pulumi.Input[_builtins.str] object_id: The uuid of the request object. For example, schema id
        :param pulumi.Input[_builtins.str] object_type: The type of the monitored object. Can be one of the following: schema
        :param pulumi.Input[Union['QualityMonitorV2ProviderConfigArgs', 'QualityMonitorV2ProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[Sequence[pulumi.Input[Union['QualityMonitorV2ValidityCheckConfigurationArgs', 'QualityMonitorV2ValidityCheckConfigurationArgsDict']]]] validity_check_configurations: Validity check configurations for anomaly detection
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _QualityMonitorV2State.__new__(_QualityMonitorV2State)

        __props__.__dict__["anomaly_detection_config"] = anomaly_detection_config
        __props__.__dict__["object_id"] = object_id
        __props__.__dict__["object_type"] = object_type
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["validity_check_configurations"] = validity_check_configurations
        return QualityMonitorV2(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="anomalyDetectionConfig")
    def anomaly_detection_config(self) -> pulumi.Output['outputs.QualityMonitorV2AnomalyDetectionConfig']:
        """
        (AnomalyDetectionConfig)
        """
        return pulumi.get(self, "anomaly_detection_config")

    @_builtins.property
    @pulumi.getter(name="objectId")
    def object_id(self) -> pulumi.Output[_builtins.str]:
        """
        The uuid of the request object. For example, schema id
        """
        return pulumi.get(self, "object_id")

    @_builtins.property
    @pulumi.getter(name="objectType")
    def object_type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of the monitored object. Can be one of the following: schema
        """
        return pulumi.get(self, "object_type")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.QualityMonitorV2ProviderConfig']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="validityCheckConfigurations")
    def validity_check_configurations(self) -> pulumi.Output[Sequence['outputs.QualityMonitorV2ValidityCheckConfiguration']]:
        """
        Validity check configurations for anomaly detection
        """
        return pulumi.get(self, "validity_check_configurations")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ConnectionArgs', 'Connection']

@pulumi.input_type
class ConnectionArgs:
    def __init__(__self__, *,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 connection_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 options: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 provider_config: Optional[pulumi.Input['ConnectionProviderConfigArgs']] = None,
                 read_only: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a Connection resource.
        :param pulumi.Input[_builtins.str] comment: Free-form text. Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] connection_type: Connection type. `MYSQL`, `POSTGRESQL`, `SNOWFLAKE`, `REDSHIFT` `SQLDW`, `SQLSERVER`, `DATABRICKS`, `SALESFORCE`, `BIGQUERY`, `WORKDAY_RAAS`, `HIVE_METASTORE`, `GA4_RAW_DATA`, `SERVICENOW`, `SALESFORCE_DATA_CLOUD`, `GLUE`, `ORACLE`, `TERADATA`, `HTTP` or `POWER_BI` are supported. Up-to-date list of connection type supported is in the [documentation](https://docs.databricks.com/query-federation/index.html#supported-data-sources). Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] name: Name of the Connection.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] options: The key value of options required by the connection, e.g. `host`, `port`, `user`, `password`, `authorization_endpoint`, `client_id`, `client_secret` or `GoogleServiceAccountKeyJson`. Please consult the [documentation](https://docs.databricks.com/query-federation/index.html#supported-data-sources) for the required option.
        :param pulumi.Input[_builtins.str] owner: Name of the connection owner.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] properties: Free-form connection properties. Change forces creation of a new resource.
        :param pulumi.Input['ConnectionProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.bool] read_only: Indicates whether the connection is read-only. Change forces creation of a new resource.
        """
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if connection_type is not None:
            pulumi.set(__self__, "connection_type", connection_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if options is not None:
            pulumi.set(__self__, "options", options)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if properties is not None:
            pulumi.set(__self__, "properties", properties)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if read_only is not None:
            pulumi.set(__self__, "read_only", read_only)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Free-form text. Change forces creation of a new resource.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter(name="connectionType")
    def connection_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Connection type. `MYSQL`, `POSTGRESQL`, `SNOWFLAKE`, `REDSHIFT` `SQLDW`, `SQLSERVER`, `DATABRICKS`, `SALESFORCE`, `BIGQUERY`, `WORKDAY_RAAS`, `HIVE_METASTORE`, `GA4_RAW_DATA`, `SERVICENOW`, `SALESFORCE_DATA_CLOUD`, `GLUE`, `ORACLE`, `TERADATA`, `HTTP` or `POWER_BI` are supported. Up-to-date list of connection type supported is in the [documentation](https://docs.databricks.com/query-federation/index.html#supported-data-sources). Change forces creation of a new resource.
        """
        return pulumi.get(self, "connection_type")

    @connection_type.setter
    def connection_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "connection_type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Connection.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def options(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        The key value of options required by the connection, e.g. `host`, `port`, `user`, `password`, `authorization_endpoint`, `client_id`, `client_secret` or `GoogleServiceAccountKeyJson`. Please consult the [documentation](https://docs.databricks.com/query-federation/index.html#supported-data-sources) for the required option.
        """
        return pulumi.get(self, "options")

    @options.setter
    def options(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "options", value)

    @_builtins.property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the connection owner.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner", value)

    @_builtins.property
    @pulumi.getter
    def properties(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Free-form connection properties. Change forces creation of a new resource.
        """
        return pulumi.get(self, "properties")

    @properties.setter
    def properties(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "properties", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['ConnectionProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['ConnectionProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="readOnly")
    def read_only(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the connection is read-only. Change forces creation of a new resource.
        """
        return pulumi.get(self, "read_only")

    @read_only.setter
    def read_only(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "read_only", value)


@pulumi.input_type
class _ConnectionState:
    def __init__(__self__, *,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 connection_id: Optional[pulumi.Input[_builtins.str]] = None,
                 connection_type: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.int]] = None,
                 created_by: Optional[pulumi.Input[_builtins.str]] = None,
                 credential_type: Optional[pulumi.Input[_builtins.str]] = None,
                 full_name: Optional[pulumi.Input[_builtins.str]] = None,
                 metastore_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 options: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 provider_config: Optional[pulumi.Input['ConnectionProviderConfigArgs']] = None,
                 provisioning_infos: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionProvisioningInfoArgs']]]] = None,
                 read_only: Optional[pulumi.Input[_builtins.bool]] = None,
                 securable_type: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.int]] = None,
                 updated_by: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Connection resources.
        :param pulumi.Input[_builtins.str] comment: Free-form text. Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] connection_id: Unique ID of the connection.
        :param pulumi.Input[_builtins.str] connection_type: Connection type. `MYSQL`, `POSTGRESQL`, `SNOWFLAKE`, `REDSHIFT` `SQLDW`, `SQLSERVER`, `DATABRICKS`, `SALESFORCE`, `BIGQUERY`, `WORKDAY_RAAS`, `HIVE_METASTORE`, `GA4_RAW_DATA`, `SERVICENOW`, `SALESFORCE_DATA_CLOUD`, `GLUE`, `ORACLE`, `TERADATA`, `HTTP` or `POWER_BI` are supported. Up-to-date list of connection type supported is in the [documentation](https://docs.databricks.com/query-federation/index.html#supported-data-sources). Change forces creation of a new resource.
        :param pulumi.Input[_builtins.int] created_at: Time at which this connection was created, in epoch milliseconds.
        :param pulumi.Input[_builtins.str] created_by: Username of connection creator.
        :param pulumi.Input[_builtins.str] credential_type: The type of credential for this connection.
        :param pulumi.Input[_builtins.str] full_name: Full name of connection.
        :param pulumi.Input[_builtins.str] metastore_id: Unique ID of the UC metastore for this connection.
        :param pulumi.Input[_builtins.str] name: Name of the Connection.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] options: The key value of options required by the connection, e.g. `host`, `port`, `user`, `password`, `authorization_endpoint`, `client_id`, `client_secret` or `GoogleServiceAccountKeyJson`. Please consult the [documentation](https://docs.databricks.com/query-federation/index.html#supported-data-sources) for the required option.
        :param pulumi.Input[_builtins.str] owner: Name of the connection owner.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] properties: Free-form connection properties. Change forces creation of a new resource.
        :param pulumi.Input['ConnectionProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[Sequence[pulumi.Input['ConnectionProvisioningInfoArgs']]] provisioning_infos: Object with the status of an asynchronously provisioned resource.
        :param pulumi.Input[_builtins.bool] read_only: Indicates whether the connection is read-only. Change forces creation of a new resource.
        :param pulumi.Input[_builtins.int] updated_at: Time at which connection this was last modified, in epoch milliseconds.
        :param pulumi.Input[_builtins.str] updated_by: Username of user who last modified the connection.
        :param pulumi.Input[_builtins.str] url: URL of the remote data source, extracted from options.
        """
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if connection_id is not None:
            pulumi.set(__self__, "connection_id", connection_id)
        if connection_type is not None:
            pulumi.set(__self__, "connection_type", connection_type)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if credential_type is not None:
            pulumi.set(__self__, "credential_type", credential_type)
        if full_name is not None:
            pulumi.set(__self__, "full_name", full_name)
        if metastore_id is not None:
            pulumi.set(__self__, "metastore_id", metastore_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if options is not None:
            pulumi.set(__self__, "options", options)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if properties is not None:
            pulumi.set(__self__, "properties", properties)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if provisioning_infos is not None:
            pulumi.set(__self__, "provisioning_infos", provisioning_infos)
        if read_only is not None:
            pulumi.set(__self__, "read_only", read_only)
        if securable_type is not None:
            pulumi.set(__self__, "securable_type", securable_type)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if updated_by is not None:
            pulumi.set(__self__, "updated_by", updated_by)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Free-form text. Change forces creation of a new resource.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter(name="connectionId")
    def connection_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique ID of the connection.
        """
        return pulumi.get(self, "connection_id")

    @connection_id.setter
    def connection_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "connection_id", value)

    @_builtins.property
    @pulumi.getter(name="connectionType")
    def connection_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Connection type. `MYSQL`, `POSTGRESQL`, `SNOWFLAKE`, `REDSHIFT` `SQLDW`, `SQLSERVER`, `DATABRICKS`, `SALESFORCE`, `BIGQUERY`, `WORKDAY_RAAS`, `HIVE_METASTORE`, `GA4_RAW_DATA`, `SERVICENOW`, `SALESFORCE_DATA_CLOUD`, `GLUE`, `ORACLE`, `TERADATA`, `HTTP` or `POWER_BI` are supported. Up-to-date list of connection type supported is in the [documentation](https://docs.databricks.com/query-federation/index.html#supported-data-sources). Change forces creation of a new resource.
        """
        return pulumi.get(self, "connection_type")

    @connection_type.setter
    def connection_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "connection_type", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Time at which this connection was created, in epoch milliseconds.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Username of connection creator.
        """
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_by", value)

    @_builtins.property
    @pulumi.getter(name="credentialType")
    def credential_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of credential for this connection.
        """
        return pulumi.get(self, "credential_type")

    @credential_type.setter
    def credential_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "credential_type", value)

    @_builtins.property
    @pulumi.getter(name="fullName")
    def full_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Full name of connection.
        """
        return pulumi.get(self, "full_name")

    @full_name.setter
    def full_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "full_name", value)

    @_builtins.property
    @pulumi.getter(name="metastoreId")
    def metastore_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique ID of the UC metastore for this connection.
        """
        return pulumi.get(self, "metastore_id")

    @metastore_id.setter
    def metastore_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "metastore_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Connection.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def options(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        The key value of options required by the connection, e.g. `host`, `port`, `user`, `password`, `authorization_endpoint`, `client_id`, `client_secret` or `GoogleServiceAccountKeyJson`. Please consult the [documentation](https://docs.databricks.com/query-federation/index.html#supported-data-sources) for the required option.
        """
        return pulumi.get(self, "options")

    @options.setter
    def options(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "options", value)

    @_builtins.property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the connection owner.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner", value)

    @_builtins.property
    @pulumi.getter
    def properties(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Free-form connection properties. Change forces creation of a new resource.
        """
        return pulumi.get(self, "properties")

    @properties.setter
    def properties(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "properties", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['ConnectionProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['ConnectionProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="provisioningInfos")
    def provisioning_infos(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionProvisioningInfoArgs']]]]:
        """
        Object with the status of an asynchronously provisioned resource.
        """
        return pulumi.get(self, "provisioning_infos")

    @provisioning_infos.setter
    def provisioning_infos(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectionProvisioningInfoArgs']]]]):
        pulumi.set(self, "provisioning_infos", value)

    @_builtins.property
    @pulumi.getter(name="readOnly")
    def read_only(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the connection is read-only. Change forces creation of a new resource.
        """
        return pulumi.get(self, "read_only")

    @read_only.setter
    def read_only(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "read_only", value)

    @_builtins.property
    @pulumi.getter(name="securableType")
    def securable_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "securable_type")

    @securable_type.setter
    def securable_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "securable_type", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Time at which connection this was last modified, in epoch milliseconds.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "updated_at", value)

    @_builtins.property
    @pulumi.getter(name="updatedBy")
    def updated_by(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Username of user who last modified the connection.
        """
        return pulumi.get(self, "updated_by")

    @updated_by.setter
    def updated_by(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_by", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL of the remote data source, extracted from options.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "url", value)


@pulumi.type_token("databricks:index/connection:Connection")
class Connection(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 connection_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 options: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 provider_config: Optional[pulumi.Input[Union['ConnectionProviderConfigArgs', 'ConnectionProviderConfigArgsDict']]] = None,
                 read_only: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        > This resource can only be used with a workspace-level provider!

        Lakehouse Federation is the query federation platform for Databricks. Databricks uses Unity Catalog to manage query federation. To make a dataset available for read-only querying using Lakehouse Federation, you create the following:

        - A connection, a securable object in Unity Catalog that specifies a path and credentials for accessing an external database system.
        - A foreign catalog

        This resource manages connections in Unity Catalog. Please note that OAuth U2M is not supported as it requires user interaction for authentication.

        ## Example Usage

        Create a connection to a MySQL database

        ```python
        import pulumi
        import pulumi_databricks as databricks

        mysql = databricks.Connection("mysql",
            name="mysql_connection",
            connection_type="MYSQL",
            comment="this is a connection to mysql db",
            options={
                "host": "test.mysql.database.azure.com",
                "port": "3306",
                "user": "user",
                "password": "password",
            },
            properties={
                "purpose": "testing",
            })
        ```

        Create a connection to a BigQuery database

        ```python
        import pulumi
        import json
        import pulumi_databricks as databricks

        bigquery = databricks.Connection("bigquery",
            name="bq_connection",
            connection_type="BIGQUERY",
            comment="this is a connection to BQ",
            options={
                "GoogleServiceAccountKeyJson": json.dumps({
                    "type": "service_account",
                    "project_id": "PROJECT_ID",
                    "private_key_id": "KEY_ID",
                    "private_key": \"\"\"-----BEGIN PRIVATE KEY-----
        PRIVATE_KEY
        -----END PRIVATE KEY-----
        \"\"\",
                    "client_email": "SERVICE_ACCOUNT_EMAIL",
                    "client_id": "CLIENT_ID",
                    "auth_uri": "https://accounts.google.com/o/oauth2/auth",
                    "token_uri": "https://accounts.google.com/o/oauth2/token",
                    "auth_provider_x509_cert_url": "https://www.googleapis.com/oauth2/v1/certs",
                    "client_x509_cert_url": "https://www.googleapis.com/robot/v1/metadata/x509/SERVICE_ACCOUNT_EMAIL",
                    "universe_domain": "googleapis.com",
                }),
            },
            properties={
                "purpose": "testing",
            })
        ```

        Create a connection to builtin Hive Metastore

        ```python
        import pulumi
        import pulumi_databricks as databricks

        hms = databricks.Connection("hms",
            name="hms-builtin",
            connection_type="HIVE_METASTORE",
            comment="This is a connection to builtin HMS",
            options={
                "builtin": "true",
            })
        ```

        Create a HTTP connection with bearer token

        ```python
        import pulumi
        import pulumi_databricks as databricks

        http_bearer = databricks.Connection("http_bearer",
            name="http_bearer",
            connection_type="HTTP",
            comment="This is a connection to a HTTP service",
            options={
                "host": "https://example.com",
                "port": "8433",
                "base_path": "/api/",
                "bearer_token": "bearer_token",
            })
        ```

        Create a HTTP connection with OAuth M2M

        ```python
        import pulumi
        import pulumi_databricks as databricks

        http_oauth = databricks.Connection("http_oauth",
            name="http_oauth",
            connection_type="HTTP",
            comment="This is a connection to a HTTP service",
            options={
                "host": "https://example.com",
                "port": "8433",
                "base_path": "/api/",
                "client_id": "client_id",
                "client_secret": "client_secret",
                "oauth_scope": "channels:read channels:history chat:write",
                "token_endpoint": "https://authorization-server.com/oauth/token",
            })
        ```

        Create a PowerBI connection with OAuth M2M

        ```python
        import pulumi
        import pulumi_databricks as databricks

        pbi = databricks.Connection("pbi",
            name="test-pbi",
            connection_type="POWER_BI",
            options={
                "authorization_endpoint": "https://login.microsoftonline.com/{tenant}/oauth2/v2.0/authorize",
                "client_id": "client_id",
                "client_secret": "client_secret",
            })
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] comment: Free-form text. Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] connection_type: Connection type. `MYSQL`, `POSTGRESQL`, `SNOWFLAKE`, `REDSHIFT` `SQLDW`, `SQLSERVER`, `DATABRICKS`, `SALESFORCE`, `BIGQUERY`, `WORKDAY_RAAS`, `HIVE_METASTORE`, `GA4_RAW_DATA`, `SERVICENOW`, `SALESFORCE_DATA_CLOUD`, `GLUE`, `ORACLE`, `TERADATA`, `HTTP` or `POWER_BI` are supported. Up-to-date list of connection type supported is in the [documentation](https://docs.databricks.com/query-federation/index.html#supported-data-sources). Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] name: Name of the Connection.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] options: The key value of options required by the connection, e.g. `host`, `port`, `user`, `password`, `authorization_endpoint`, `client_id`, `client_secret` or `GoogleServiceAccountKeyJson`. Please consult the [documentation](https://docs.databricks.com/query-federation/index.html#supported-data-sources) for the required option.
        :param pulumi.Input[_builtins.str] owner: Name of the connection owner.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] properties: Free-form connection properties. Change forces creation of a new resource.
        :param pulumi.Input[Union['ConnectionProviderConfigArgs', 'ConnectionProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.bool] read_only: Indicates whether the connection is read-only. Change forces creation of a new resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ConnectionArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        > This resource can only be used with a workspace-level provider!

        Lakehouse Federation is the query federation platform for Databricks. Databricks uses Unity Catalog to manage query federation. To make a dataset available for read-only querying using Lakehouse Federation, you create the following:

        - A connection, a securable object in Unity Catalog that specifies a path and credentials for accessing an external database system.
        - A foreign catalog

        This resource manages connections in Unity Catalog. Please note that OAuth U2M is not supported as it requires user interaction for authentication.

        ## Example Usage

        Create a connection to a MySQL database

        ```python
        import pulumi
        import pulumi_databricks as databricks

        mysql = databricks.Connection("mysql",
            name="mysql_connection",
            connection_type="MYSQL",
            comment="this is a connection to mysql db",
            options={
                "host": "test.mysql.database.azure.com",
                "port": "3306",
                "user": "user",
                "password": "password",
            },
            properties={
                "purpose": "testing",
            })
        ```

        Create a connection to a BigQuery database

        ```python
        import pulumi
        import json
        import pulumi_databricks as databricks

        bigquery = databricks.Connection("bigquery",
            name="bq_connection",
            connection_type="BIGQUERY",
            comment="this is a connection to BQ",
            options={
                "GoogleServiceAccountKeyJson": json.dumps({
                    "type": "service_account",
                    "project_id": "PROJECT_ID",
                    "private_key_id": "KEY_ID",
                    "private_key": \"\"\"-----BEGIN PRIVATE KEY-----
        PRIVATE_KEY
        -----END PRIVATE KEY-----
        \"\"\",
                    "client_email": "SERVICE_ACCOUNT_EMAIL",
                    "client_id": "CLIENT_ID",
                    "auth_uri": "https://accounts.google.com/o/oauth2/auth",
                    "token_uri": "https://accounts.google.com/o/oauth2/token",
                    "auth_provider_x509_cert_url": "https://www.googleapis.com/oauth2/v1/certs",
                    "client_x509_cert_url": "https://www.googleapis.com/robot/v1/metadata/x509/SERVICE_ACCOUNT_EMAIL",
                    "universe_domain": "googleapis.com",
                }),
            },
            properties={
                "purpose": "testing",
            })
        ```

        Create a connection to builtin Hive Metastore

        ```python
        import pulumi
        import pulumi_databricks as databricks

        hms = databricks.Connection("hms",
            name="hms-builtin",
            connection_type="HIVE_METASTORE",
            comment="This is a connection to builtin HMS",
            options={
                "builtin": "true",
            })
        ```

        Create a HTTP connection with bearer token

        ```python
        import pulumi
        import pulumi_databricks as databricks

        http_bearer = databricks.Connection("http_bearer",
            name="http_bearer",
            connection_type="HTTP",
            comment="This is a connection to a HTTP service",
            options={
                "host": "https://example.com",
                "port": "8433",
                "base_path": "/api/",
                "bearer_token": "bearer_token",
            })
        ```

        Create a HTTP connection with OAuth M2M

        ```python
        import pulumi
        import pulumi_databricks as databricks

        http_oauth = databricks.Connection("http_oauth",
            name="http_oauth",
            connection_type="HTTP",
            comment="This is a connection to a HTTP service",
            options={
                "host": "https://example.com",
                "port": "8433",
                "base_path": "/api/",
                "client_id": "client_id",
                "client_secret": "client_secret",
                "oauth_scope": "channels:read channels:history chat:write",
                "token_endpoint": "https://authorization-server.com/oauth/token",
            })
        ```

        Create a PowerBI connection with OAuth M2M

        ```python
        import pulumi
        import pulumi_databricks as databricks

        pbi = databricks.Connection("pbi",
            name="test-pbi",
            connection_type="POWER_BI",
            options={
                "authorization_endpoint": "https://login.microsoftonline.com/{tenant}/oauth2/v2.0/authorize",
                "client_id": "client_id",
                "client_secret": "client_secret",
            })
        ```

        :param str resource_name: The name of the resource.
        :param ConnectionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConnectionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 connection_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 options: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 provider_config: Optional[pulumi.Input[Union['ConnectionProviderConfigArgs', 'ConnectionProviderConfigArgsDict']]] = None,
                 read_only: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConnectionArgs.__new__(ConnectionArgs)

            __props__.__dict__["comment"] = comment
            __props__.__dict__["connection_type"] = connection_type
            __props__.__dict__["name"] = name
            __props__.__dict__["options"] = None if options is None else pulumi.Output.secret(options)
            __props__.__dict__["owner"] = owner
            __props__.__dict__["properties"] = properties
            __props__.__dict__["provider_config"] = provider_config
            __props__.__dict__["read_only"] = read_only
            __props__.__dict__["connection_id"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["created_by"] = None
            __props__.__dict__["credential_type"] = None
            __props__.__dict__["full_name"] = None
            __props__.__dict__["metastore_id"] = None
            __props__.__dict__["provisioning_infos"] = None
            __props__.__dict__["securable_type"] = None
            __props__.__dict__["updated_at"] = None
            __props__.__dict__["updated_by"] = None
            __props__.__dict__["url"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["options"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Connection, __self__).__init__(
            'databricks:index/connection:Connection',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            comment: Optional[pulumi.Input[_builtins.str]] = None,
            connection_id: Optional[pulumi.Input[_builtins.str]] = None,
            connection_type: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.int]] = None,
            created_by: Optional[pulumi.Input[_builtins.str]] = None,
            credential_type: Optional[pulumi.Input[_builtins.str]] = None,
            full_name: Optional[pulumi.Input[_builtins.str]] = None,
            metastore_id: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            options: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            owner: Optional[pulumi.Input[_builtins.str]] = None,
            properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            provider_config: Optional[pulumi.Input[Union['ConnectionProviderConfigArgs', 'ConnectionProviderConfigArgsDict']]] = None,
            provisioning_infos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConnectionProvisioningInfoArgs', 'ConnectionProvisioningInfoArgsDict']]]]] = None,
            read_only: Optional[pulumi.Input[_builtins.bool]] = None,
            securable_type: Optional[pulumi.Input[_builtins.str]] = None,
            updated_at: Optional[pulumi.Input[_builtins.int]] = None,
            updated_by: Optional[pulumi.Input[_builtins.str]] = None,
            url: Optional[pulumi.Input[_builtins.str]] = None) -> 'Connection':
        """
        Get an existing Connection resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] comment: Free-form text. Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] connection_id: Unique ID of the connection.
        :param pulumi.Input[_builtins.str] connection_type: Connection type. `MYSQL`, `POSTGRESQL`, `SNOWFLAKE`, `REDSHIFT` `SQLDW`, `SQLSERVER`, `DATABRICKS`, `SALESFORCE`, `BIGQUERY`, `WORKDAY_RAAS`, `HIVE_METASTORE`, `GA4_RAW_DATA`, `SERVICENOW`, `SALESFORCE_DATA_CLOUD`, `GLUE`, `ORACLE`, `TERADATA`, `HTTP` or `POWER_BI` are supported. Up-to-date list of connection type supported is in the [documentation](https://docs.databricks.com/query-federation/index.html#supported-data-sources). Change forces creation of a new resource.
        :param pulumi.Input[_builtins.int] created_at: Time at which this connection was created, in epoch milliseconds.
        :param pulumi.Input[_builtins.str] created_by: Username of connection creator.
        :param pulumi.Input[_builtins.str] credential_type: The type of credential for this connection.
        :param pulumi.Input[_builtins.str] full_name: Full name of connection.
        :param pulumi.Input[_builtins.str] metastore_id: Unique ID of the UC metastore for this connection.
        :param pulumi.Input[_builtins.str] name: Name of the Connection.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] options: The key value of options required by the connection, e.g. `host`, `port`, `user`, `password`, `authorization_endpoint`, `client_id`, `client_secret` or `GoogleServiceAccountKeyJson`. Please consult the [documentation](https://docs.databricks.com/query-federation/index.html#supported-data-sources) for the required option.
        :param pulumi.Input[_builtins.str] owner: Name of the connection owner.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] properties: Free-form connection properties. Change forces creation of a new resource.
        :param pulumi.Input[Union['ConnectionProviderConfigArgs', 'ConnectionProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[Sequence[pulumi.Input[Union['ConnectionProvisioningInfoArgs', 'ConnectionProvisioningInfoArgsDict']]]] provisioning_infos: Object with the status of an asynchronously provisioned resource.
        :param pulumi.Input[_builtins.bool] read_only: Indicates whether the connection is read-only. Change forces creation of a new resource.
        :param pulumi.Input[_builtins.int] updated_at: Time at which connection this was last modified, in epoch milliseconds.
        :param pulumi.Input[_builtins.str] updated_by: Username of user who last modified the connection.
        :param pulumi.Input[_builtins.str] url: URL of the remote data source, extracted from options.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConnectionState.__new__(_ConnectionState)

        __props__.__dict__["comment"] = comment
        __props__.__dict__["connection_id"] = connection_id
        __props__.__dict__["connection_type"] = connection_type
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["created_by"] = created_by
        __props__.__dict__["credential_type"] = credential_type
        __props__.__dict__["full_name"] = full_name
        __props__.__dict__["metastore_id"] = metastore_id
        __props__.__dict__["name"] = name
        __props__.__dict__["options"] = options
        __props__.__dict__["owner"] = owner
        __props__.__dict__["properties"] = properties
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["provisioning_infos"] = provisioning_infos
        __props__.__dict__["read_only"] = read_only
        __props__.__dict__["securable_type"] = securable_type
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["updated_by"] = updated_by
        __props__.__dict__["url"] = url
        return Connection(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Free-form text. Change forces creation of a new resource.
        """
        return pulumi.get(self, "comment")

    @_builtins.property
    @pulumi.getter(name="connectionId")
    def connection_id(self) -> pulumi.Output[_builtins.str]:
        """
        Unique ID of the connection.
        """
        return pulumi.get(self, "connection_id")

    @_builtins.property
    @pulumi.getter(name="connectionType")
    def connection_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Connection type. `MYSQL`, `POSTGRESQL`, `SNOWFLAKE`, `REDSHIFT` `SQLDW`, `SQLSERVER`, `DATABRICKS`, `SALESFORCE`, `BIGQUERY`, `WORKDAY_RAAS`, `HIVE_METASTORE`, `GA4_RAW_DATA`, `SERVICENOW`, `SALESFORCE_DATA_CLOUD`, `GLUE`, `ORACLE`, `TERADATA`, `HTTP` or `POWER_BI` are supported. Up-to-date list of connection type supported is in the [documentation](https://docs.databricks.com/query-federation/index.html#supported-data-sources). Change forces creation of a new resource.
        """
        return pulumi.get(self, "connection_type")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.int]:
        """
        Time at which this connection was created, in epoch milliseconds.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> pulumi.Output[_builtins.str]:
        """
        Username of connection creator.
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter(name="credentialType")
    def credential_type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of credential for this connection.
        """
        return pulumi.get(self, "credential_type")

    @_builtins.property
    @pulumi.getter(name="fullName")
    def full_name(self) -> pulumi.Output[_builtins.str]:
        """
        Full name of connection.
        """
        return pulumi.get(self, "full_name")

    @_builtins.property
    @pulumi.getter(name="metastoreId")
    def metastore_id(self) -> pulumi.Output[_builtins.str]:
        """
        Unique ID of the UC metastore for this connection.
        """
        return pulumi.get(self, "metastore_id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the Connection.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def options(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        The key value of options required by the connection, e.g. `host`, `port`, `user`, `password`, `authorization_endpoint`, `client_id`, `client_secret` or `GoogleServiceAccountKeyJson`. Please consult the [documentation](https://docs.databricks.com/query-federation/index.html#supported-data-sources) for the required option.
        """
        return pulumi.get(self, "options")

    @_builtins.property
    @pulumi.getter
    def owner(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the connection owner.
        """
        return pulumi.get(self, "owner")

    @_builtins.property
    @pulumi.getter
    def properties(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        Free-form connection properties. Change forces creation of a new resource.
        """
        return pulumi.get(self, "properties")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.ConnectionProviderConfig']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="provisioningInfos")
    def provisioning_infos(self) -> pulumi.Output[Sequence['outputs.ConnectionProvisioningInfo']]:
        """
        Object with the status of an asynchronously provisioned resource.
        """
        return pulumi.get(self, "provisioning_infos")

    @_builtins.property
    @pulumi.getter(name="readOnly")
    def read_only(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether the connection is read-only. Change forces creation of a new resource.
        """
        return pulumi.get(self, "read_only")

    @_builtins.property
    @pulumi.getter(name="securableType")
    def securable_type(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "securable_type")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.int]:
        """
        Time at which connection this was last modified, in epoch milliseconds.
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="updatedBy")
    def updated_by(self) -> pulumi.Output[_builtins.str]:
        """
        Username of user who last modified the connection.
        """
        return pulumi.get(self, "updated_by")

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Output[_builtins.str]:
        """
        URL of the remote data source, extracted from options.
        """
        return pulumi.get(self, "url")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['KnowledgeAssistantKnowledgeSourceArgs', 'KnowledgeAssistantKnowledgeSource']

@pulumi.input_type
class KnowledgeAssistantKnowledgeSourceArgs:
    def __init__(__self__, *,
                 description: pulumi.Input[_builtins.str],
                 display_name: pulumi.Input[_builtins.str],
                 parent: pulumi.Input[_builtins.str],
                 source_type: pulumi.Input[_builtins.str],
                 file_table: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFileTableArgs']] = None,
                 files: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFilesArgs']] = None,
                 index: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceIndexArgs']] = None,
                 provider_config: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceProviderConfigArgs']] = None):
        """
        The set of arguments for constructing a KnowledgeAssistantKnowledgeSource resource.
        :param pulumi.Input[_builtins.str] description: Description of the knowledge source.
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, optional unless included in update_mask
        :param pulumi.Input[_builtins.str] display_name: Human-readable display name of the knowledge source.
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, optional unless included in update_mask
        :param pulumi.Input[_builtins.str] parent: Parent resource where this source will be created.
               Format: knowledge-assistants/{knowledge_assistant_id}
        :param pulumi.Input[_builtins.str] source_type: The type of the source: "index", "files", or "file_table".
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, this field is ignored
        :param pulumi.Input['KnowledgeAssistantKnowledgeSourceProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "parent", parent)
        pulumi.set(__self__, "source_type", source_type)
        if file_table is not None:
            pulumi.set(__self__, "file_table", file_table)
        if files is not None:
            pulumi.set(__self__, "files", files)
        if index is not None:
            pulumi.set(__self__, "index", index)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Input[_builtins.str]:
        """
        Description of the knowledge source.
        Required when creating a Knowledge Source.
        When updating a Knowledge Source, optional unless included in update_mask
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[_builtins.str]:
        """
        Human-readable display name of the knowledge source.
        Required when creating a Knowledge Source.
        When updating a Knowledge Source, optional unless included in update_mask
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter
    def parent(self) -> pulumi.Input[_builtins.str]:
        """
        Parent resource where this source will be created.
        Format: knowledge-assistants/{knowledge_assistant_id}
        """
        return pulumi.get(self, "parent")

    @parent.setter
    def parent(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "parent", value)

    @_builtins.property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of the source: "index", "files", or "file_table".
        Required when creating a Knowledge Source.
        When updating a Knowledge Source, this field is ignored
        """
        return pulumi.get(self, "source_type")

    @source_type.setter
    def source_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "source_type", value)

    @_builtins.property
    @pulumi.getter(name="fileTable")
    def file_table(self) -> Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFileTableArgs']]:
        return pulumi.get(self, "file_table")

    @file_table.setter
    def file_table(self, value: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFileTableArgs']]):
        pulumi.set(self, "file_table", value)

    @_builtins.property
    @pulumi.getter
    def files(self) -> Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFilesArgs']]:
        return pulumi.get(self, "files")

    @files.setter
    def files(self, value: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFilesArgs']]):
        pulumi.set(self, "files", value)

    @_builtins.property
    @pulumi.getter
    def index(self) -> Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceIndexArgs']]:
        return pulumi.get(self, "index")

    @index.setter
    def index(self, value: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceIndexArgs']]):
        pulumi.set(self, "index", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)


@pulumi.input_type
class _KnowledgeAssistantKnowledgeSourceState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 file_table: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFileTableArgs']] = None,
                 files: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFilesArgs']] = None,
                 index: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceIndexArgs']] = None,
                 knowledge_cutoff_time: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceProviderConfigArgs']] = None,
                 source_type: Optional[pulumi.Input[_builtins.str]] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering KnowledgeAssistantKnowledgeSource resources.
        :param pulumi.Input[_builtins.str] create_time: (string) - Timestamp when this knowledge source was created
        :param pulumi.Input[_builtins.str] description: Description of the knowledge source.
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, optional unless included in update_mask
        :param pulumi.Input[_builtins.str] display_name: Human-readable display name of the knowledge source.
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, optional unless included in update_mask
        :param pulumi.Input[_builtins.str] knowledge_cutoff_time: (string) - Timestamp representing the cutoff before which content in this knowledge source is being ingested
        :param pulumi.Input[_builtins.str] name: (string) - Full resource name:
               knowledge-assistants/{knowledge_assistant_id}/knowledge-sources/{knowledge_source_id}
        :param pulumi.Input[_builtins.str] parent: Parent resource where this source will be created.
               Format: knowledge-assistants/{knowledge_assistant_id}
        :param pulumi.Input['KnowledgeAssistantKnowledgeSourceProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.str] source_type: The type of the source: "index", "files", or "file_table".
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, this field is ignored
        :param pulumi.Input[_builtins.str] state: (string) - Possible values are: `FAILED_UPDATE`, `UPDATED`, `UPDATING`
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if file_table is not None:
            pulumi.set(__self__, "file_table", file_table)
        if files is not None:
            pulumi.set(__self__, "files", files)
        if index is not None:
            pulumi.set(__self__, "index", index)
        if knowledge_cutoff_time is not None:
            pulumi.set(__self__, "knowledge_cutoff_time", knowledge_cutoff_time)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if parent is not None:
            pulumi.set(__self__, "parent", parent)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if source_type is not None:
            pulumi.set(__self__, "source_type", source_type)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Timestamp when this knowledge source was created
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "create_time", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the knowledge source.
        Required when creating a Knowledge Source.
        When updating a Knowledge Source, optional unless included in update_mask
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Human-readable display name of the knowledge source.
        Required when creating a Knowledge Source.
        When updating a Knowledge Source, optional unless included in update_mask
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter(name="fileTable")
    def file_table(self) -> Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFileTableArgs']]:
        return pulumi.get(self, "file_table")

    @file_table.setter
    def file_table(self, value: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFileTableArgs']]):
        pulumi.set(self, "file_table", value)

    @_builtins.property
    @pulumi.getter
    def files(self) -> Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFilesArgs']]:
        return pulumi.get(self, "files")

    @files.setter
    def files(self, value: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFilesArgs']]):
        pulumi.set(self, "files", value)

    @_builtins.property
    @pulumi.getter
    def index(self) -> Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceIndexArgs']]:
        return pulumi.get(self, "index")

    @index.setter
    def index(self, value: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceIndexArgs']]):
        pulumi.set(self, "index", value)

    @_builtins.property
    @pulumi.getter(name="knowledgeCutoffTime")
    def knowledge_cutoff_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Timestamp representing the cutoff before which content in this knowledge source is being ingested
        """
        return pulumi.get(self, "knowledge_cutoff_time")

    @knowledge_cutoff_time.setter
    def knowledge_cutoff_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "knowledge_cutoff_time", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Full resource name:
        knowledge-assistants/{knowledge_assistant_id}/knowledge-sources/{knowledge_source_id}
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def parent(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Parent resource where this source will be created.
        Format: knowledge-assistants/{knowledge_assistant_id}
        """
        return pulumi.get(self, "parent")

    @parent.setter
    def parent(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the source: "index", "files", or "file_table".
        Required when creating a Knowledge Source.
        When updating a Knowledge Source, this field is ignored
        """
        return pulumi.get(self, "source_type")

    @source_type.setter
    def source_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "source_type", value)

    @_builtins.property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Possible values are: `FAILED_UPDATE`, `UPDATED`, `UPDATING`
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "state", value)


@pulumi.type_token("databricks:index/knowledgeAssistantKnowledgeSource:KnowledgeAssistantKnowledgeSource")
class KnowledgeAssistantKnowledgeSource(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 file_table: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceFileTableArgs', 'KnowledgeAssistantKnowledgeSourceFileTableArgsDict']]] = None,
                 files: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceFilesArgs', 'KnowledgeAssistantKnowledgeSourceFilesArgsDict']]] = None,
                 index: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceIndexArgs', 'KnowledgeAssistantKnowledgeSourceIndexArgsDict']]] = None,
                 parent: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceProviderConfigArgs', 'KnowledgeAssistantKnowledgeSourceProviderConfigArgsDict']]] = None,
                 source_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the knowledge source.
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, optional unless included in update_mask
        :param pulumi.Input[_builtins.str] display_name: Human-readable display name of the knowledge source.
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, optional unless included in update_mask
        :param pulumi.Input[_builtins.str] parent: Parent resource where this source will be created.
               Format: knowledge-assistants/{knowledge_assistant_id}
        :param pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceProviderConfigArgs', 'KnowledgeAssistantKnowledgeSourceProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.str] source_type: The type of the source: "index", "files", or "file_table".
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, this field is ignored
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: KnowledgeAssistantKnowledgeSourceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

        :param str resource_name: The name of the resource.
        :param KnowledgeAssistantKnowledgeSourceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(KnowledgeAssistantKnowledgeSourceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 file_table: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceFileTableArgs', 'KnowledgeAssistantKnowledgeSourceFileTableArgsDict']]] = None,
                 files: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceFilesArgs', 'KnowledgeAssistantKnowledgeSourceFilesArgsDict']]] = None,
                 index: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceIndexArgs', 'KnowledgeAssistantKnowledgeSourceIndexArgsDict']]] = None,
                 parent: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceProviderConfigArgs', 'KnowledgeAssistantKnowledgeSourceProviderConfigArgsDict']]] = None,
                 source_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = KnowledgeAssistantKnowledgeSourceArgs.__new__(KnowledgeAssistantKnowledgeSourceArgs)

            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__.__dict__["description"] = description
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["file_table"] = file_table
            __props__.__dict__["files"] = files
            __props__.__dict__["index"] = index
            if parent is None and not opts.urn:
                raise TypeError("Missing required property 'parent'")
            __props__.__dict__["parent"] = parent
            __props__.__dict__["provider_config"] = provider_config
            if source_type is None and not opts.urn:
                raise TypeError("Missing required property 'source_type'")
            __props__.__dict__["source_type"] = source_type
            __props__.__dict__["create_time"] = None
            __props__.__dict__["knowledge_cutoff_time"] = None
            __props__.__dict__["name"] = None
            __props__.__dict__["state"] = None
        super(KnowledgeAssistantKnowledgeSource, __self__).__init__(
            'databricks:index/knowledgeAssistantKnowledgeSource:KnowledgeAssistantKnowledgeSource',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            display_name: Optional[pulumi.Input[_builtins.str]] = None,
            file_table: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceFileTableArgs', 'KnowledgeAssistantKnowledgeSourceFileTableArgsDict']]] = None,
            files: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceFilesArgs', 'KnowledgeAssistantKnowledgeSourceFilesArgsDict']]] = None,
            index: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceIndexArgs', 'KnowledgeAssistantKnowledgeSourceIndexArgsDict']]] = None,
            knowledge_cutoff_time: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            parent: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceProviderConfigArgs', 'KnowledgeAssistantKnowledgeSourceProviderConfigArgsDict']]] = None,
            source_type: Optional[pulumi.Input[_builtins.str]] = None,
            state: Optional[pulumi.Input[_builtins.str]] = None) -> 'KnowledgeAssistantKnowledgeSource':
        """
        Get an existing KnowledgeAssistantKnowledgeSource resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] create_time: (string) - Timestamp when this knowledge source was created
        :param pulumi.Input[_builtins.str] description: Description of the knowledge source.
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, optional unless included in update_mask
        :param pulumi.Input[_builtins.str] display_name: Human-readable display name of the knowledge source.
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, optional unless included in update_mask
        :param pulumi.Input[_builtins.str] knowledge_cutoff_time: (string) - Timestamp representing the cutoff before which content in this knowledge source is being ingested
        :param pulumi.Input[_builtins.str] name: (string) - Full resource name:
               knowledge-assistants/{knowledge_assistant_id}/knowledge-sources/{knowledge_source_id}
        :param pulumi.Input[_builtins.str] parent: Parent resource where this source will be created.
               Format: knowledge-assistants/{knowledge_assistant_id}
        :param pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceProviderConfigArgs', 'KnowledgeAssistantKnowledgeSourceProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.str] source_type: The type of the source: "index", "files", or "file_table".
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, this field is ignored
        :param pulumi.Input[_builtins.str] state: (string) - Possible values are: `FAILED_UPDATE`, `UPDATED`, `UPDATING`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _KnowledgeAssistantKnowledgeSourceState.__new__(_KnowledgeAssistantKnowledgeSourceState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["file_table"] = file_table
        __props__.__dict__["files"] = files
        __props__.__dict__["index"] = index
        __props__.__dict__["knowledge_cutoff_time"] = knowledge_cutoff_time
        __props__.__dict__["name"] = name
        __props__.__dict__["parent"] = parent
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["source_type"] = source_type
        __props__.__dict__["state"] = state
        return KnowledgeAssistantKnowledgeSource(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Timestamp when this knowledge source was created
        """
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[_builtins.str]:
        """
        Description of the knowledge source.
        Required when creating a Knowledge Source.
        When updating a Knowledge Source, optional unless included in update_mask
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[_builtins.str]:
        """
        Human-readable display name of the knowledge source.
        Required when creating a Knowledge Source.
        When updating a Knowledge Source, optional unless included in update_mask
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter(name="fileTable")
    def file_table(self) -> pulumi.Output[Optional['outputs.KnowledgeAssistantKnowledgeSourceFileTable']]:
        return pulumi.get(self, "file_table")

    @_builtins.property
    @pulumi.getter
    def files(self) -> pulumi.Output[Optional['outputs.KnowledgeAssistantKnowledgeSourceFiles']]:
        return pulumi.get(self, "files")

    @_builtins.property
    @pulumi.getter
    def index(self) -> pulumi.Output[Optional['outputs.KnowledgeAssistantKnowledgeSourceIndex']]:
        return pulumi.get(self, "index")

    @_builtins.property
    @pulumi.getter(name="knowledgeCutoffTime")
    def knowledge_cutoff_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Timestamp representing the cutoff before which content in this knowledge source is being ingested
        """
        return pulumi.get(self, "knowledge_cutoff_time")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Full resource name:
        knowledge-assistants/{knowledge_assistant_id}/knowledge-sources/{knowledge_source_id}
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def parent(self) -> pulumi.Output[_builtins.str]:
        """
        Parent resource where this source will be created.
        Format: knowledge-assistants/{knowledge_assistant_id}
        """
        return pulumi.get(self, "parent")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.KnowledgeAssistantKnowledgeSourceProviderConfig']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of the source: "index", "files", or "file_table".
        Required when creating a Knowledge Source.
        When updating a Knowledge Source, this field is ignored
        """
        return pulumi.get(self, "source_type")

    @_builtins.property
    @pulumi.getter
    def state(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Possible values are: `FAILED_UPDATE`, `UPDATED`, `UPDATING`
        """
        return pulumi.get(self, "state")

